<?php


namespace App\Services;

use App\Repositories\Contracts\RhawnRawRepository;
use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Services\Kafka\KafkaService;
use App\Services\ThirdPlatform\Api\IntegleApiService;
use App\Services\ThirdPlatform\PlatformAbstractService;

class InteglePlatformService extends PlatformAbstractService
{

    public function __construct(ThirdApiPlatformRepository $thirdApiPlatformRepository)
    {
        $this->setPlatformName('integle');
        parent::__construct($thirdApiPlatformRepository);
    }

    /**
     * 批量更新产品到integle平台
     */
    public function batchUpdateProducts()
    {
        $status = $this->checkApiPlatformStatus($this->platformName);
        if($status){
            $this->getPlatformInfo($this->platformName);

            $rhawnChemicalsService = app(RhawnChemicalsService::class);
            $limit = $this->platformInfo['platform_params']['batchNums'];
            $page = 0;

            while(true) {
                $rawList = $rhawnChemicalsService->getChemicalRawList($page * $limit, $limit);
                if (!$rawList) {
                    break;
                }
                $rawIdList = [];
                foreach ($rawList as $raw) {
                    $rawIdList[] = $raw['r_id'];
                }
                $packages = $rhawnChemicalsService->getChemicalPackage($rawIdList);
                $newPackages = [];
                if($packages){
                    foreach($packages as $pack){
                        $newPackages[$pack['r_code']] = $pack;
                    }
                }
                if(!empty($rawList)){
                    app(KafkaService::class)->produerSend(
                        [
                            'params' => ['rawList' => $rawList,'packageList' => $newPackages],
                            'consumer' => 'App\Services\InteglePlatformService',
                            'method' => 'batchUpdateApi'
                        ]
                    );
                    $page ++;
                }
            }
        }
    }

    public function batchUpdateApi($updateData)
    {
        $result = app(IntegleApiService::class)->pushBatchUpdateProduct($updateData);
        if($result){
            if($result['status'] === false){
                app(KafkaService::class)->produerSend(
                    [
                        'consumer' => 'App\Services\InteglePlatformService',
                        'method' => 'batchUpdateApi',
                        'params' => $updateData
                    ]
                );
            }
        }
        unset($result['status']);

        $logsContent = [
            'apiParams' => $updateData,
            'apiReturn' => $result
        ];
        app(SysLogService::class)->addApiLogs($logsContent);
    }
}
