<?php

namespace App\Services\Kafka;

use App\Services\SysLogService;
use App\Support\Traits\KafkaConfigHelpers;
use longlang\phpkafka\Consumer\ConsumeMessage;
use longlang\phpkafka\Consumer\Consumer;
use longlang\phpkafka\Producer\Producer;


class KafkaService
{
    use KafkaConfigHelpers;

    protected $kafkaProducerConfig = null;
    protected $kafkaConsumerConfig = null;
    protected $config = null;

    public function __construct($config)
    {
        $this->kafkaProducerConfig = $this->getProducerConfig($config);
        //$this->kafkaConsumerConfig = $this->getConsumerConfig($config);

        $this->config = $config;
    }

    /**
     * 推送记录
     * @param $contentValue
     * @param null $topic
     */
    public function produerSend($contentValue, $topic = null)
    {
        try {
            $kafkaTopic = $topic;
            if ($kafkaTopic == null) {
                $kafkaTopic = $this->config['topic'];
            }
            $key = uniqid($kafkaTopic, true);
            $producer = new Producer($this->kafkaProducerConfig);
            $producer->send($kafkaTopic, json_encode($contentValue), $key);

            app(SysLogService::class)->addOperationLogs(
                [
                    'content' => $contentValue
                ]
            );

        } catch (\Exception $exception) {
            $this->errLog($exception);
            throw $exception;
        }
    }


    /**
     * 开启消费者
     */
    public function startConsumer()
    {
        $consumer = new Consumer($this->getConsumerConfig($this->config), function (ConsumeMessage $message) {

            $consumer = $message->getConsumer();
            $kafkaMessage = json_decode($message->getValue(),true);

            try{
                app($kafkaMessage['consumer'])->{$kafkaMessage['method']}($kafkaMessage['params']);
                $consumer->ack($message); // 手动提交
            }catch(\Exception $exception){
                $this->errLog($exception);
            }

            $consumer->stop();
        });
        $consumer->start();
        $consumer->close();
    }

    public function errLog($exception)
    {
        app(SysLogService::class)->addOperationLogs(
            [
                'error' => $exception->getCode(),
                'message' => $exception->getMessage()
            ]
        );
    }

}
