<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services;

use App\Export\BaseExport;
use App\Export\WuxiLab\WuxiLabExport;
use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Services\Kafka\KafkaService;
use App\Services\ThirdPlatform\Api\WuxiApiService;
use App\Services\ThirdPlatform\PlatformAbstractService;
use longlang\phpkafka\Protocol\ApiVersions\ApiVersionsResponse;

class WuxiLabService extends PlatformAbstractService
{

    public function __construct(ThirdApiPlatformRepository $thirdApiPlatformRepository)
    {
        $this->setPlatformName('wuxi_appTec');
        parent::__construct($thirdApiPlatformRepository);
    }

    /**
     * 批量更新商品
     */
    public function batchUpdateProducts()
    {
        $status = $this->checkApiPlatformStatus($this->platformName);
        if($status){
            $this->getPlatformInfo($this->platformName);

            $rhawnChemicalsService = app(RhawnChemicalsService::class);
            $limit = $this->platformInfo['platform_params']['batchNums'];
            $page = 0;

            while(true) {
                $rawList = $rhawnChemicalsService->getChemicalRawList($page * $limit, $limit);
                if (!$rawList) {
                    break;
                }
                $rawIdList = [];
                foreach ($rawList as $raw) {
                    $rawIdList[] = $raw['r_id'];
                }
                $packages = $rhawnChemicalsService->getChemicalPackage($rawIdList);
                $newPackages = [];
                if($packages){
                    foreach($packages as $pack){
                        $newPackages[$pack['r_code']] = $pack;
                    }
                }
                if(!empty($rawList)){
                    /*if(
                        $this->batchUpdateApi(
                            ['rawList' => $rawList,'packageList' => $newPackages]
                        )
                    ){
                        //$page = intval($count / $limit) * $limit;
                        $page ++;
                        usleep(3000);
                    }*/
                    app(KafkaService::class)->produerSend(
                        [
                            'params' => ['rawList' => $rawList,'packageList' => $newPackages],
                            'consumer' => 'App\Services\WuxiLabService',
                            'method' => 'batchUpdateApi'

                        ]
                    );
                }
                break;
            }
        }
    }

    public function batchUpdateApi($updateData)
    {
        $result = app(WuxiApiService::class)->pushBatchUpdateProduct($updateData);
        if($result){
            if($result['status'] === false){
                app(KafkaService::class)->produerSend(
                    [
                        '' =>'',
                        'params' => $updateData
                    ]
                );
            }
        }
        unset($result['status']);

        $logsContent = [
            'apiParams' => $updateData,
            'apiReturn' => $result
        ];
        app(SysLogService::class)->addApiLogs($logsContent);
    }

    /**
     * 初始化生成产品excel文档
     */
    public function initCreateProductsToExcel($exportLimit)
    {
        $rhawnChemicalsService = app(RhawnChemicalsService::class);
        $limit = $exportLimit;
        $page = 0;

        while(true) {
            $rawList = $rhawnChemicalsService->getChemicalRawList($page * $limit, $limit);
            if (!$rawList) {
                break;
            }
            $rawIdList = [];
            foreach ($rawList as $raw) {
                $rawIdList[] = $raw['r_id'];
            }
            $packages = $rhawnChemicalsService->getChemicalPackage($rawIdList);
            $newPackages = [];
            if($packages){
                foreach($packages as $pack){
                    $newPackages[$pack['r_code']] = $pack;
                }
            }
            if(!empty($rawList)){
                app(WuxiLabExport::class)->saveExcel(
                    ['rawList' => $rawList,'packageList' => $newPackages]
                );
            }
            break;
        }
    }

}
